@@ -1,4 +1,7 @@
-from data_manipulation import data_types, geopandas, pandas, psycopg2
+from . import data_types
+from . import geopandas
+from . import pandas
+from . import psycopg2
 from ._version import get_versions
 
 __version__ = get_versions()['version']
